import { createStore } from "vuex";
import {ElMessage} from 'element-plus'
import {apiUserInfo} from '@/api/user.js'
const token=localStorage.getItem('token')||''
const breadcrumb=sessionStorage.getItem('breadcrumb')?JSON.parse(sessionStorage.getItem('breadcrumb')):[]
export default createStore({
  state: {
    globalImgUrls:{//图片配置资源
      chartWait:'https://hzstatic.hzinsights.com/static/icon/hzyb/chart_wait.png',
      chartEmpty:'https://hzstatic.hzinsights.com/static/icon/hzyb/chart_empty.png',
      activityNoAuth:'https://hzstatic.hzinsights.com/static/icon/hzyb/activity_no_auth.png',
      imgSuccess:'https://hzstatic.hzinsights.com/static/icon/hzyb/success_icon.png',
      loginTop:'https://hzstatic.hzinsights.com/static/icon/hzyb/login_top_img.png',
      idCardExp:'https://hzstatic.hzinsights.com/static/icon/hzyb/idcard_exp.jpg',
      defaultAvatar:'https://hzstatic.hzinsights.com/static/icon/hzyb/default_avatar.png',
      ficcServiceImg:'https://hzstatic.hzinsights.com/static/icon/hzyb/ficc_service_pc.png',
      specialColumnBanner:'https://hzstatic.hzinsights.com/static/icon/hzyb/special_column_banner_pc.png'
    },
    showLogin:false,//是否显示微信扫码弹窗
    token:token,
    userInfo:null,
    audioData:{
      INS:null,//音频实例
      list:[],//音频数据{time:音频时长,url:音频地址,name:音频名称}
      index:0,//当前播放第几个
      activityId:0,//活动的id
      reportId:0,//报告的id
      paused:true,//当前音频播放状态
      show:false,//是否显示音频弹窗
    },

    activityItemStatus:{//活动详情中某个活动点击了会议提醒\报名 更新列表状态
      activityId:0,
      type:'',// 会议、报名
    },

    breadCrumbList:breadcrumb,//面包屑数据
  },
  mutations: {
    //显示微信扫码登陆
    showLogin(state,e){
      state.showLogin=true
    },
      
    // 获取token
    getToken(state,e){
      console.log(e);
      state.token=e
      localStorage.setItem('token',e)
    },
    // 获取个人信息
    setUserInfo(state,e){
      state.userInfo=e
    },

    // 设置音频播放
    addAudio(state,e){
      state.audioData.index=e.index
      state.audioData.list=e.list
      state.audioData.activityId=e.activityId||0
      state.audioData.reportId=e.reportId||0
      state.audioData.show=true
      state.audioData.INS.play()
    },
    //切换音频
    changeAudio(state,e){
      if(e==='before'){//点击按钮切换上一首
        if(state.audioData.index===0){
          ElMessage('当前为第一首')
        }else{
          state.audioData.index--
        }
      }else if(e==='next'){//点击按钮切换下一首
        if(state.audioData.index==state.audioData.list.length-1){
          ElMessage('当前为最后一首')
        }else{
          state.audioData.index++
        }
      }else if(e==='auto'){//自动播放切换下一首
        if(state.audioData.index==state.audioData.list.length-1){
          // ElMessage('当前为最后一首')
          state.audioData.list=[]
          state.audioData.index=0
          state.audioData.activityId=0
          state.audioData.reportId=0
          state.audioData.INS=null
          state.audioData.show=false
          state.audioData.paused=false
        }else{
          state.audioData.index++
        }
      }
    },
    // 关闭音频
    closeAudio(state,e){
      state.audioData.list=[]
      state.audioData.index=0
      state.audioData.activityId=0
      state.audioData.reportId=0
      state.audioData.INS=null
      state.audioData.show=false
      state.audioData.paused=false
    },
    //音频状态切换
    audioStatusChange(state,e){
      if(e=='paused'){
        state.audioData.paused=true
      }else{
        state.audioData.paused=false
        state.audioData.show=true
      }
    },
    //关闭音频弹窗
    closeAudioPop(state){
      state.audioData.show=false
    },

    // 更新活动列表某项状态
    updateActivityStatus(state,e){
      state.activityItemStatus.activityId=e.activityId
      state.activityItemStatus.type=e.type
    },

    // 设置面包屑数据
    setBreadCrumb(state,data){
      // 如果是侧边栏 清除路由栈
      if (data.meta.isRoot) {
        let obj = {
          name: data.matched[0].meta.title,
          path:''
        }
        state.breadCrumbList=[obj]
      }else{
        //判断路由栈中是否包含当前路由
        let index = -1
        state.breadCrumbList.forEach((item,e) => {
          if(item.path === data.fullPath){
            index=e
          }
        });
        if (index==-1) {
          state.breadCrumbList.push({name:data.meta.title,path:data.fullPath})
        }else{
          const arr=state.breadCrumbList.slice(0,index+1)
          state.breadCrumbList=arr
        }
      }

      sessionStorage.setItem('breadcrumb',JSON.stringify(state.breadCrumbList))
    },

    // 修改面包屑
    modifyBreadCrumb(state,data){
      let temarr=state.breadCrumbList
      temarr[temarr.length-1].name=data
      state.breadCrumbList=temarr
      sessionStorage.setItem('breadcrumb',JSON.stringify(state.breadCrumbList))
    }

  },
  actions: {
    // 获取个人信息
    async getUserInfo(context){
      const res=await apiUserInfo()
      if(res.code===200){
        context.commit('setUserInfo',res.data)
      }
    }
  },
  modules: {},
});